---
jupyter:
  kernelspec:
    display_name: Maxima
    language: maxima
    name: maxima
---

## maxima misc

```maxima
kill(all)$
```

```maxima
f(x) := 1/(x^2+l^2)^(3/2);
```

```maxima
integrate(f(x), x);
```

```maxima
tex(%)$
```

```maxima

```
